<?php
/**
 * Create Plugin Options Page
 *
 * @package     CloudWeb\DSGVO
 * @since       1.0.0
 * @author      cloudweb team @adrian
 * @link        https://www.cloudweb.ch
 * @license     GNU General Public License 2.0+
 *
 */

if ( ! defined( 'ABSPATH' ) ) {
	die( "Oh, silly, there's nothing to see here." );
}

class DSGVO_Admin {
	/**
	 * Holds the values to be used in the fields callbacks
	 */
	private $options, $latest, $default_lang, $langs;

	/**
	 * Init
	 */
	function __construct() {

		$this->options = get_option('cookie_bar');
		$this->latest = get_option('cookie_bar_1_3');

		if ( function_exists('icl_object_id') ) {
			$default_lang = apply_filters('wpml_default_language', NULL );
			if($default_lang) {
				$this->default_lang = $default_lang;
			} else {
				$wpml_options = get_option( 'icl_sitepress_settings' );
				$default_lang = $wpml_options['default_language'];
				if($default_lang) {
					$this->default_lang = $default_lang;
				} else {
					$default_lang = get_locale();
					$default_lang = explode('_', $default_lang);
					$this->default_lang = $default_lang[0];
				}
			}
		} else {
			$default_lang = get_locale();
			$default_lang = explode('_', $default_lang);
			$this->default_lang = $default_lang[0];
		}

		add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );
		add_action( 'admin_init', array( $this, 'admin_page_init' ) );
		add_action( 'admin_init', array( $this, 'admin_settings_main' ) );
		add_action( 'admin_enqueue_scripts', array($this, 'scripts') );
		add_action( 'admin_enqueue_scripts', array($this, 'styles') );

		if(!$this->latest) {
			add_action('admin_init', array( $this, 'adapt_to_1_3' ), 100);
		}

	}

	public function adapt_to_1_3() {
		global $wpdb;
		if(isset($this->options['cookie_bar_position'])) {
			$this->options['cookie_bar_position'] = 'whole-width-bottom';
			$wpdb->update(
				$wpdb->prefix.'options',
				array(
					'option_value' => maybe_serialize($this->options)
				),
				array(
					'option_name' => 'cookie_bar'
				)
			);
			update_option('cookie_bar_1_3', 1, 1);
		}
	}

	public function scripts( $hook ) {
		if($hook == 'tools_page_dsgvo-admin') {
			wp_enqueue_style( 'wp-color-picker' );
			wp_enqueue_script( 'dsgvo-admin-js', DSGVO_ASSETS_URL.'js/admin.js', array('wp-color-picker', 'jquery'), '', true );
			wp_localize_script('dsgvo-admin-js', 'dsgvoadmin', array(
				'translations' => array(
					'copied_to_clip' => __('Copied to clipboard', 'dsgvo-fur-die-schweiz')
				)
			));
			wp_enqueue_script( 'jquery-ui-slider' );
		}
	}

	public function styles( $hook ) {

		if($hook == 'tools_page_dsgvo-admin') {
			wp_enqueue_style( 'dsvgo-jquery-ui-theme-smoothness', '//code.jquery.com/ui/1.12.1/themes/base/jquery-ui.css' );
			wp_enqueue_style( 'dsvgo-admin-css', DSGVO_ASSETS_URL.'css/admin.css' );
		}

	}

	/**
	 * Create options page
	 */
	public function add_plugin_page() {

		// This page will be under "Tools"
		add_submenu_page('tools.php', 'DSGVO', 'DSGVO', 'manage_options', 'dsgvo-admin', array( $this, 'create_admin_page' ));

	}

	/**
	 * Options page callback
	 */
	public function create_admin_page() {
		// Set class property
	?>
        <div class="wrap">
            <form id="dsgvo_options_form" method="post" action="options.php">
				<?php
					settings_fields( 'dsgvo-settings-group' );
					do_settings_sections( 'dsgvo-admin-tabs' );
				?>
				<div class="dsgvo-admin-tab" id="dsgvo-admin-tab-settings">
					<?php do_settings_sections( 'dsgvo-admin-settings' ); ?>
				</div>
				<div class="dsgvo-admin-tab" id="dsgvo-admin-tab-optout" style="display:none;">
					<?php do_settings_sections( 'dsgvo-admin-optout' ); ?>
				</div>
				<div class="dsgvo-admin-tab" id="dsgvo-admin-tab-design" style="display:none;">
					<?php do_settings_sections( 'dsgvo-admin-design' ); ?>
				</div>
				<?php submit_button(); ?>
            </form>
        </div>
	<?php
	}

	/**
	 * Register and add settings
	 */
	public function admin_page_init() {

		register_setting('dsgvo-settings-group', 'cookie_bar', array( $this, 'sanitize' ));

	}

	public function admin_settings_main() {

		$behaviour = $functionality = '';

		if ( function_exists('icl_object_id') ) {
			$langs = icl_get_languages('skip_missing=0&orderby=KEY&order=DESC&link_empty_to=str');
			unset($langs[strtolower($this->default_lang)]);
		}

		$sections = array(

			'dsgvo_tabs' 	 => array(
				'id'		=> 'dsgvo_tabs',
				'label' 	=> '',
				'callback' 	=> 'cookie_bar_tabs',
				'page'		=> 'dsgvo-admin-tabs'
			),
			'dsgvo_settings' => array(

				'id' 		=> 'dsgvo_settings',
				'label' 	=> __('DSGVO Settings', 'dsgvo-fur-die-schweiz'),
				'callback' 	=> 'admin_settings_section_desc',
				'page' 		=> 'dsgvo-admin-settings',
				'fields' 	=> array(
					'cookie_bar_activate' => array(
						'id'		=> 'cookie_bar_activate',
						'type'		=> 'checkbox',
						'label' 	=> __('Plugin active?', 'dsgvo-fur-die-schweiz'),
						'label_for' => 'cookie_bar_activate'
					),
					'cookie_bar_position' => array(
						'id'		=> 'cookie_bar_position',
						'type' 		=> 'select',
						'label' 	=> __('Position / Display', 'dsgvo-fur-die-schweiz'),
						'options' 	=> array(
							'whole-width-top' 		=> __('Whole Width / Top', 'dsgvo-fur-die-schweiz'),
							'whole-width-bottom' 	=> __('Whole Width / Bottom', 'dsgvo-fur-die-schweiz'),
							'top-left' 				=> __('Top Left', 'dsgvo-fur-die-schweiz'),
							'top-right' 			=> __('Top Right', 'dsgvo-fur-die-schweiz'),
							'bottom-left' 			=> __('Bottom Left', 'dsgvo-fur-die-schweiz'),
							'bottom-right' 			=> __('Bottom Right', 'dsgvo-fur-die-schweiz')
						),
						'label_for' => 'cookie_bar_position'
					)
				)

			),
			'dsgvo_optout' => array(

				'id' 		=> 'dsgvo_optout',
				'label' 	=> __('DSGVO Opt Out', 'dsgvo-fur-die-schweiz'),
				'callback' 	=> 'admin_settings_section_desc',
				'page' 		=> 'dsgvo-admin-optout',
				'fields' 	=> array(
					'cookie_bar_opt_out_enabled' => array(
						'id'			=> 'cookie_bar_opt_out_enabled',
						'type'			=> 'select',
						'label'			=> __('Opt Out Enabled', 'dsgvo-fur-die-schweiz'),
						'label_for'		=> 'cookie_bar_opt_out_enabled',
						'options'		=> array(
							0 => __('No', 'dsgvo-fur-die-schweiz'),
							1 => __('Yes', 'dsgvo-fur-die-schweiz')
						)
					)
				)

			),
			'dsgvo_design' => array(

				'id' 		=> 'dsgvo_design',
				'label' 	=> __('DSGVO Design', 'dsgvo-fur-die-schweiz'),
				'callback' 	=> 'admin_settings_section_desc',
				'page' 		=> 'dsgvo-admin-design',
				'fields' 	=> array(
					'cookie_bar_activate' => array(
						'id'		=> 'cookie_bar_background_color',
						'type'		=> 'text',
						'label' 	=> __('Background color', 'dsgvo-fur-die-schweiz'),
						'label_for' => 'cookie_bar_background_color',
						'classes'	=> 'dsgvo-colorpicker'
					),
					'cookie_bar_text_color'	=> array(
						'id'		=> 'cookie_bar_text_color',
						'type'		=> 'text',
						'label'		=> __('Text Color', 'dsgvo-fur-die-schweiz'),
						'label_for'	=> 'cookie_bar_text_color',
						'classes'	=> 'dsgvo-colorpicker'
					),
					'cookie_bar_links_color'	=> array(
						'id'		=> 'cookie_bar_links_color',
						'type'		=> 'text',
						'label'		=> __('Links Color', 'dsgvo-fur-die-schweiz'),
						'label_for'	=> 'cookie_bar_links_color',
						'classes'	=> 'dsgvo-colorpicker'
					),
					'cookie_bar_button_background_color' => array(
						'id'		=> 'cookie_bar_button_background_color',
						'type'		=> 'text',
						'label'		=> __('Agree Button Background Color', 'dsgvo-fur-die-schweiz'),
						'label_for'	=> 'cookie_bar_button_background_color',
						'classes'	=> 'dsgvo-colorpicker'
					),
					'cookie_bar_button_text_color' => array(
						'id'		=> 'cookie_bar_button_text_color',
						'type'		=> 'text',
						'label'		=> __('Agree Button Text Color', 'dsgvo-fur-die-schweiz'),
						'label_for'	=> 'cookie_bar_button_text_color',
						'classes'	=> 'dsgvo-colorpicker'
					),
					'cookie_bar_optout_link_color' => array(
						'id'		=> 'cookie_bar_optout_link_color',
						'type'		=> 'text',
						'label'		=> __('Opt Out Link/Button text Color', 'dsgvo-fur-die-schweiz'),
						'label_for'	=> 'cookie_bar_optout_link_color',
						'classes'	=> 'dsgvo-colorpicker'
					),
					'cookie_bar_optout_button_bg_color' => array(
						'id'		=> 'cookie_bar_optout_button_bg_color',
						'type'		=> 'text',
						'label'		=> __('Opt Out Button Background Color<br/><small>Only applies if the Optout Link Type is set to Button</small>', 'dsgvo-fur-die-schweiz'),
						'label_for'	=> 'cookie_bar_optout_button_bg_color',
						'classes'	=> 'dsgvo-colorpicker'
					),
					'cookie_bar_transparency' => array(
						'id'		=> 'cookie_bar_transparency',
						'type'		=> 'handle',
						'label'		=> __('Opacity', 'dsgvo-fur-die-schweiz'),
						'label_for'	=> 'cookie_bar_transparency',
						'classes'	=> 'dsgvo-colorpicker'
					)
				)

			)

		);

		if ( !function_exists('icl_object_id') ) {
			$default_lang_string = '';
		} else {
			$default_lang_string = 'Default Language '.strtoupper($this->default_lang);
		}


		$section_settings_default_fields = array(
			'cookie_bar_text_message' => array(
				'id'			=> 'cookie_bar_text_message',
				'type'			=> 'textarea',
				'label'			=> __('Message<br/><small>'.$default_lang_string.'</small>', 'dsgvo-fur-die-schweiz'),
				'placeholder'	=> __('Set Cookie Message '.$default_lang_string, 'dsgvo-fur-die-schweiz'),
				'label_for' 	=> 'cookie_bar_text_message'
			),
			'cookie_bar_url_text'	  => array(
				'id'			=> 'cookie_bar_url_text',
				'type'			=> 'text',
				'label'			=> __('Read more text<br/><small>'.$default_lang_string.'</small>', 'dsgvo-fur-die-schweiz'),
				'label_for'		=> 'cookie_bar_url_text'
			),
			'cookie_bar_more_info_url'	=> array(
				'id'			=> 'cookie_bar_more_info_url',
				'type'			=> 'text',
				'label'			=> __('Read more link<br/><small>'.$default_lang_string.'</small>', 'dsgvo-fur-die-schweiz'),
				'label_for'		=> 'cookie_bar_more_info_url'
			),
			'cookie_bar_button_text'	=> array(
				'id'			=> 'cookie_bar_button_text',
				'type'			=> 'text',
				'label'			=> __('Button text<br/><small>'.$default_lang_string.'</small>', 'dsgvo-fur-die-schweiz'),
				'label_for'		=> 'cookie_bar_button_text'
			)
		);

		if ( function_exists('icl_object_id') ) {

			foreach($langs as $prefix => $lang) {
				$section_settings_default_fields['cookie_bar_'.$prefix.'_tab'] = array(
					'type' 	=> 'tab_heading',
					'id' 	=> 'tab_heading_'.$prefix,
					'label' => '<img src="'.$lang['country_flag_url'].'" alt="'.$prefix.'" /> '.$lang['native_name']
				);
				$section_settings_default_fields['cookie_bar_'.$prefix.'_text_message'] = array(
					'id'			=> 'cookie_bar_'.$prefix.'_text_message',
					'type'			=> 'textarea',
					'label'			=> __('Message '.strtoupper($prefix), 'dsgvo-fur-die-schweiz'),
					'placeholder'	=> __('Set Cookie Message '.strtoupper($prefix), 'dsgvo-fur-die-schweiz'),
					'label_for' 	=> 'cookie_bar_'.$prefix.'_text_message'
				);
				$section_settings_default_fields['cookie_bar_'.$prefix.'_url_text'] = array(
					'id'			=> 'cookie_bar_'.$prefix.'_url_text',
					'type'			=> 'text',
					'label'			=> __('Read more text '.strtoupper($prefix), 'dsgvo-fur-die-schweiz'),
					'label_for'		=> 'cookie_bar_'.$prefix.'_url_text'
				);
				$section_settings_default_fields['cookie_bar_'.$prefix.'_more_info_url'] = array(
					'id'			=> 'cookie_bar_'.$prefix.'_more_info_url',
					'type'			=> 'text',
					'label'			=> __('Read more link '.strtoupper($prefix), 'dsgvo-fur-die-schweiz'),
					'label_for'		=> 'cookie_bar_'.$prefix.'_more_info_url'
				);
				$section_settings_default_fields['cookie_bar_'.$prefix.'_button_text'] = array(
					'id'			=> 'cookie_bar_'.$prefix.'_button_text',
					'type'			=> 'text',
					'label'			=> __('Button text '.strtoupper($prefix), 'dsgvo-fur-die-schweiz'),
					'label_for'		=> 'cookie_bar_'.$prefix.'_button_text'
				);
			}
		}

		foreach($section_settings_default_fields as $ssdf => $conf) {
			$sections['dsgvo_settings']['fields'][$ssdf] = $conf;
		}

		if(isset($this->options['cookie_bar_opt_out_enabled']) && $this->options['cookie_bar_opt_out_enabled'] == 1) {

			$sections['dsgvo_optout']['fields']['cookie_bar_opt_out_type'] = array(
				'id'			=> 'cookie_bar_opt_out_type',
				'type'			=> 'select',
				'label'			=> __('Opt Out Type', 'dsgvo-fur-die-schweiz'),
				'label_for'		=> 'cookie_bar_opt_out_type',
				'options'		=> array(
					''			=> '- Select -',
					'ga' 		=> 'Google Analytics',
					'gtm'		=> 'Google Tag Manager',
					'custom' 	=> __('Custom', 'dsgvo-fur-die-schweiz')
				)
			);

			if((isset($this->options['cookie_bar_opt_out_type']) && $this->options['cookie_bar_opt_out_type'] == 'ga') || (isset($this->options['cookie_bar_opt_out_type']) && $this->options['cookie_bar_opt_out_type'] == 'gtm')) {

				if($this->options['cookie_bar_opt_out_type'] == 'ga') {

					$sections['dsgvo_optout']['fields']['cookie_bar_google_property_id'] = array(
						'id' 		=> 'cookie_bar_google_property_id',
						'type' 		=> 'text',
						'label' 	=> 'Google Property ID',
						'label_for' => 'cookie_bar_google_property_id',
						'desc'		=> __('Only works if you have Google Analytics already embedded on your website.', 'dsgvo-fur-die-schweiz')
					);

					$behaviour = 'ga';
					$functionality = 'gproperty="'.$this->options['cookie_bar_google_property_id'].'"';

				}

				if($this->options['cookie_bar_opt_out_type'] == 'gtm') {

					$sections['dsgvo_optout']['fields']['cookie_bar_optout_function_name'] = array(
						'id' 		=> 'cookie_bar_optout_function_name',
						'type' 		=> 'text',
						'label' 	=> __('GTM function to call', 'dsgvo-fur-die-schweiz'),
						'label_for' => 'cookie_bar_optout_function_name',
						'desc'		=> __('Defined inside the GTM script.<br/>Please use the standard paranthesis of a JS function. Eg.: <strong>callme()</strong> and not callme.<br/>If needed, you can also add parameters to the function call.', 'dsgvo-fur-die-schweiz')
					);

					$behaviour = 'gtm';
					$functionality = 'gtmfunc="'.$this->options['cookie_bar_optout_function_name'].'"';

				}

				$sections['dsgvo_optout']['fields']['cookie_bar_optout_link_text'] = array(
					'id' 		=> 'cookie_bar_optout_link_text',
					'type' 		=> 'text',
					'label' 	=> __('Link text<br/><small>'.$default_lang_string.'</small>', 'dsgvo-fur-die-schweiz'),
					'label_for' => 'cookie_bar_optout_link_text'
				);

				$sections['dsgvo_optout']['fields']['cookie_bar_optout_success_message'] = array(
					'id' 		=> 'cookie_bar_optout_success_message',
					'type' 		=> 'textarea',
					'label' 	=> __('Success Message<br/><small>'.$default_lang_string.'</small>', 'dsgvo-fur-die-schweiz'),
					'label_for' => 'cookie_bar_optout_success_message',
					'desc'		=> 'This message will appear when the OptOut link or button is clicked'
				);

				if ( function_exists('icl_object_id') ) {

					foreach($langs as $prefix => $lang) {

						$sections['dsgvo_optout']['fields']['cookie_bar_'.$prefix.'_optout_link_text'] = array(
							'id' 		=> 'cookie_bar_'.$prefix.'_optout_link_text',
							'type' 		=> 'text',
							'label' 	=> __('<img src="'.$lang['country_flag_url'].'" alt="'.$lang['native_name'].'" /> Link text', 'dsgvo-fur-die-schweiz'),
							'label_for' => 'cookie_bar_'.$prefix.'_optout_link_text'
						);

						$sections['dsgvo_optout']['fields']['cookie_bar_'.$prefix.'_optout_success_message'] = array(
							'id' 		=> 'cookie_bar_'.$prefix.'_optout_success_message',
							'type' 		=> 'textarea',
							'label' 	=> __('<img src="'.$lang['country_flag_url'].'" alt="'.$lang['native_name'].'" /> Success Message', 'dsgvo-fur-die-schweiz'),
							'label_for' => 'cookie_bar_'.$prefix.'_optout_success_message',
							'desc'		=> 'This message will appear when the OptOut link or button is clicked'
						);

					}

				}

			} elseif(isset($this->options['cookie_bar_opt_out_type']) && $this->options['cookie_bar_opt_out_type'] == 'custom') {

				$sections['dsgvo_optout']['fields']['cookie_bar_custom_optout_events'] = array(
					'id' 			=> 'cookie_bar_customer_optout_events',
					'type' 			=> 'textarea',
					'label' 		=> __('Custom OptOut Events', 'dsgvo-fur-die-schweiz'),
					'placeholder' 	=> __('Set custom code here', 'dsgvo-fur-die-schweiz'),
					'label_for'		=> 'cookie_bar_customer_optout_events',
					'desc'			=> __('The output of the code you place here will appear beside the Acceptance button in the frontend.', 'dsgvo-fur-die-schweiz')
				);

				$behaviour = 'custom';

			}

			$sections['dsgvo_optout']['fields']['cookie_bar_optout_already_accepted_message'] = array(
				'id' 		=> 'cookie_bar_optout_already_accepted_message',
				'type' 		=> 'textarea',
				'label' 	=> __('Already opted out message<br/><small>'.$default_lang_string.'</small>', 'dsgvo-fur-die-schweiz'),
				'label_for' => 'cookie_bar_optout_already_accepted_message'
			);

			if ( function_exists('icl_object_id') ) {

				foreach($langs as $prefix => $lang) {

					$sections['dsgvo_optout']['fields']['cookie_bar_'.$prefix.'_optout_already_accepted_message'] = array(
						'id' 		=> 'cookie_bar_'.$prefix.'_optout_already_accepted_message',
						'type' 		=> 'textarea',
						'label' 	=> __('<img src="'.$lang['country_flag_url'].'" alt="'.$lang['native_name'].'" /> Already opted out message', 'dsgvo-fur-die-schweiz'),
						'label_for' => 'cookie_bar_'.$prefix.'_optout_already_accepted_message'
					);

				}

			}

			if($behaviour != 'custom') {

				$shortcodevaluedefault = '[dsgvo type="'.$behaviour.'" '.$functionality.' link_text="'.$this->options['cookie_bar_optout_link_text'].'" success_message="'.$this->options['cookie_bar_optout_success_message'].'" already_optedout_message="'.$this->options['cookie_bar_optout_already_accepted_message'].'"]';

			} else {

				$shortcodevaluedefault = '[dsgvo type="custom"]';

			}

			$sections['dsgvo_optout']['fields']['cookie_bar_optout_shortcode'] = array(
				'id' 		=> 'cookie_bar_optout_shortcode',
				'type' 		=> 'textarea',
				'classes'	=> 'cookie_bar_optout_shortcode',
				'label' 	=> __('Shortcode<br/><small>'.$default_lang_string.'</small>', 'dsgvo-fur-die-schweiz'),
				'label_for' => 'cookie_bar_optout_shortcode',
				'readonly'	=> true,
				'desc'		=> __('You can use this shortcode in any post or page. Click on the textbox to copy the shortcode to your clipboard.', 'dsgvo-fur-die-schweiz'),
				'value'		=> $shortcodevaluedefault
			);

			if ( function_exists('icl_object_id') ) {

				foreach($langs as $prefix => $lang) {

					if($behaviour != 'custom') {

						$shortcodevalue = '[dsgvo type="'.$behaviour.'" '.$functionality.' link_text="'.$this->options['cookie_bar_'.$prefix.'_optout_link_text'].'" success_message="'.$this->options['cookie_bar_'.$prefix.'_optout_success_message'].'" already_optedout_message="'.$this->options['cookie_bar_'.$prefix.'_optout_already_accepted_message'].'"]';

					} else {

						$shortcodevalue = '[dsgvo type="custom"]';

					}

					$sections['dsgvo_optout']['fields']['cookie_bar_'.$prefix.'_optout_shortcode'] = array(
						'id' 		=> 'cookie_bar_'.$prefix.'_optout_shortcode',
						'type' 		=> 'textarea',
						'classes'	=> 'cookie_bar_optout_shortcode',
						'label' 	=> __('<img src="'.$lang['country_flag_url'].'" alt="'.$lang['native_name'].'" /> Shortcode', 'dsgvo-fur-die-schweiz'),
						'label_for' => 'cookie_bar_'.$prefix.'_optout_shortcode',
						'readonly'	=> true,
						'desc'		=> __('You can use this shortcode in any post or page. Click on the textbox to copy the shortcode to your clipboard.', 'dsgvo-fur-die-schweiz'),
						'value'		=> $shortcodevalue
					);

				}

			}

		}

		foreach($sections as $sectionid => $section) {

			add_settings_section($sectionid, __($section['label'], 'dsgvo-fur-die-schweiz'), array($this, $section['callback']), $section['page']);

			if(isset($section['fields'])) {

				foreach($section['fields'] as $fieldid => $field) {
					add_settings_field(
						$fieldid,
						__($field['label'], 'dsgvo-fur-die-schweiz'),
						array($this, isset($field['callback']) ? $field['callback'] : 'generate_form_field'),
						isset($field['page']) ? $field['page'] : $section['page'],
						isset($field['section']) ? $field['section'] : $sectionid,
						$section['fields'][$fieldid]
					);
				}

			}

		}

	}

	public function generate_form_field($args = null) {

		switch($args['type']) {

			case 'text' :

				if(isset($args['value'])) {
					$thevalue = $args['value'];
				} else {
					$thevalue = isset($this->options[$args['id']] ) ? esc_attr( $this->options[$args['id']]) : '';
				}

				printf(
					'<input type="text" id="'.$args['id'].'" name="cookie_bar['.$args['id'].']" %s %s value="%s" %s /><div class="dsgvo-admin-field-desc">%s</div>',
					isset($args['classes']) ? 'class="'.$args['classes'].'"' : '',
					isset($args['placeholder']) ? 'placeholder="'.__($args['placeholder'], 'dsgvo-fur-die-schweiz').'"' : '',
					$thevalue,
					isset($args['readonly']) ? 'readonly' : '',
					isset($args['desc']) ? __($args['desc'], 'dsgvo-fur-die-schweiz') : ''
				);

			break;

			case 'checkbox' :

				printf(
					'<input id="'.$args['id'].'" name="cookie_bar['.$args['id'].']" type="checkbox" %s %s %s /><div class="dsgvo-admin-field-desc">%s</div>',
					isset($args['classes']) ? 'class="'.$args['classes'].'"' : '',
					(isset( $this->options[$args['id']] ) && $this->options[$args['id']] == 'on') ? ' checked="checked" ' : '',
					isset( $args['readonly'] ) ? 'readonly' : '',
					isset($args['desc']) ? __($args['desc'], 'dsgvo-fur-die-schweiz') : ''
				);

			break;

			case 'select' :

				if(isset($args['value'])) {
					$thevalue = $args['value'];
				} else {
					$thevalue = isset($this->options[$args['id']] ) ? esc_attr( $this->options[$args['id']]) : '';
				}

				printf(
					'<select %s id="'.$args['id'].'" name="cookie_bar['.$args['id'].']" %s>',
					isset( $args['classes'] ) ? 'class="'.$args['classes'].'"' : '',
					isset( $args['readonly'] ) ? 'readonly' : ''
				);
				foreach($args['options'] as $value => $label) {
					$selected = ( $thevalue == $value ) ? 'selected="selected"' : '';
					printf( '<option value="%s" %s>%s</option>', $value, $selected, $label );
				}
				printf( '</select><div class="dsgvo-admin-field-desc">%s</div>', isset($args['desc']) ? __($args['desc'], 'dsgvo-fur-die-schweiz') : '' );

			break;

			case 'textarea' :

				if(isset($args['value'])) {
					$thevalue = $args['value'];
				} else {
					$thevalue = isset($this->options[$args['id']] ) ? esc_attr( $this->options[$args['id']]) : '';
				}

				printf(
					'<textarea name="cookie_bar['.$args['id'].']" id="'.$args['id'].'" cols="47" rows="2" %s %s %s>%s</textarea><div class="dsgvo-admin-field-desc">%s</div>',
					isset($args['classes']) ? 'class="'.$args['classes'].'"' : '',
					isset($args['placeholder']) ? 'placeholder="'.__($args['placeholder'], 'dsgvo-fur-die-schweiz').'"' : '',
					isset($args['readonly']) ? 'readonly' : '',
					$thevalue,
					isset($args['desc']) ? __($args['desc'], 'dsgvo-fur-die-schweiz') : ''
				);

			break;

			case 'handle' :

				if(isset($args['value'])) {
					$thevalue = $args['value'];
				} else {
					$thevalue = isset($this->options[$args['id']] ) ? esc_attr( $this->options[$args['id']]) : '';
				}

				printf(
					'<div id="'.$args['id'].'_handle_container"><div id="'.$args['id'].'_handle" class="ui-slider-handle" data-handle="%s"></div></div><input  id="'.$args['id'].'_value" type="hidden" name="cookie_bar['.$args['id'].']" value="'.$this->options[$args['id']] .'" /><div class="dsgvo-admin-field-desc">%s</div>	',
					$thevalue,
					isset($args['desc']) ? __($args['desc'], 'dsgvo-fur-die-schweiz') : ''
				);

			break;

			case 'tab_heading':

				printf(
					'<div id="%s" class="tab_heading">%s</div>',
					$args['id'],
					$args['value']
				);

			break;

		}


	}

	/**
	 * Sanitize each setting field as needed
	 *
	 * @param array $input Contains all settings fields as array keys
	 */
	public function sanitize( $input ) {

		$new_input = array();

		$fields = array(
			'filter_var' => array(
				'cookie_bar_activate' => FILTER_SANITIZE_STRING
			),
			'sanitize' => array(
				'cookie_bar_background_color',
				'cookie_bar_background_color',
				'cookie_bar_text_color',
				'cookie_bar_links_color',
				'cookie_bar_button_background_color',
				'cookie_bar_button_text_color',
				'cookie_bar_position',
				'cookie_bar_button_text',
				'cookie_bar_text_message',
				'cookie_bar_url_text',
				'cookie_bar_more_info_url',
				'cookie_bar_transparency',
				'cookie_bar_opt_out_enabled',
				'cookie_bar_opt_out_type',
				'cookie_bar_google_property_id',
				'cookie_bar_optout_link_text',
				'cookie_bar_optout_success_message',
				'cookie_bar_optout_link_color',
				'cookie_bar_optout_button_bg_color',
				'cookie_bar_optout_already_accepted_message'
			),
			'no_filter' => array(
				'cookie_bar_optout_function_name',
				'cookie_bar_customer_optout_events'
			)
		);

		if ( function_exists('icl_object_id') ) {

			$langs = icl_get_languages('skip_missing=0&orderby=KEY&order=DESC&link_empty_to=str');
			unset($langs[strtolower($this->default_lang)]);

			foreach($langs as $prefix => $lang) {
				$fields['sanitize'][] = 'cookie_bar_'.$prefix.'_text_message';
				$fields['sanitize'][] = 'cookie_bar_'.$prefix.'_url_text';
				$fields['sanitize'][] = 'cookie_bar_'.$prefix.'_more_info_url';
				$fields['sanitize'][] = 'cookie_bar_'.$prefix.'_button_text';
				$fields['sanitize'][] = 'cookie_bar_'.$prefix.'_optout_link_text';
				$fields['sanitize'][] = 'cookie_bar_'.$prefix.'_optout_success_message';
				$fields['sanitize'][] = 'cookie_bar_'.$prefix.'_optout_already_accepted_message';
			}
		}

		foreach($fields as $type => $field) {

			switch($type) {

				case 'filter_var' :

					foreach($field as $id => $suffix) {
						$new_input[$id] = filter_var($input[$id], $suffix);
					}

				break;

				case 'sanitize' :

					foreach($field as $id) {
						$new_input[$id] = sanitize_text_field($input[$id]);
					}

				break;
				case 'no_filter':

					foreach($field as $id) {
						$new_input[$id] = $input[$id];
					}

				break;
			}

		}

		return $new_input;
	}

	/**
	 * Print the Section text
	 */
	public function admin_settings_section_desc($args) {
		//echo 'Enter your settings below:';
		if($args['id'] == 'dsgvo_optout') {
			echo '<a href="https://www.cloudweb.ch/dsgvo-optout" target="_blank">'.__('How to generate Opt Out Link', 'dsgvo-fur-die-schweiz').'</a>';
		}
	}

	public function cookie_bar_tabs() {
		$tabs = array('settings' => __('Settings', 'dsgvo-fur-die-schweiz'), 'optout' => 'Opt Out', 'design' => __('Design', 'dsgvo-fur-die-schweiz'));
		echo '<h2 class="nav-tab-wrapper dsgvo-tab-wrap">';
		$tabcount = 1;
		foreach($tabs as $id => $label) {
			printf(
				'<a href="#" class="nav-tab %s" data-tabid="'.$id.'">'.$label.'</a>',
				($tabcount == 1) ? 'nav-tab-active' : ''
			);
			$tabcount++;
		}
		echo '</h2>';
	}

}

if ( is_admin() ) {
	new DSGVO_Admin();
}
?>
