<?php
/**
 * Plugin FrontEnd
 *
 * @package     CloudWeb\DSGVO
 * @since       1.0.0
 * @author      cloudweb team @adrian
 * @link        https://www.cloudweb.ch
 * @license     GNU General Public License 2.0+
 *
 */

if ( ! defined( 'ABSPATH' ) ) {
	die( "Oh, silly, there's nothing to see here." );
}

class DSGVO_Frontend {

	private $options, $plugin_active, $plugin_show_notification_bar, $default_lang;

	function __construct() {

		$this->options                      = get_option( 'cookie_bar' );
		$this->plugin_active                = $this->options['cookie_bar_activate'] == 'on' ? true : false;
		$this->plugin_show_notification_bar = isset( $this->options['cookie_bar_activate'] ) ? $this->options['cookie_bar_activate'] : '';

		if ( function_exists('icl_object_id') ) {
			global $sitepress;
			$this->default_lang = $sitepress->get_default_language();
		} else {
			$default_lang = get_locale();
			$default_lang = explode('_', $default_lang);
			$this->default_lang = $default_lang[0];
		}

		if ( $this->plugin_active || $this->plugin_show_notification_bar === 'on' ) {
			add_action( 'wp_enqueue_scripts', array( $this, 'load_styles' ) );
			add_action( 'wp_enqueue_scripts', array( $this, 'load_scripts' ) );
			if(!isset($_COOKIE['cookie_consent_status'])) {
				add_action( 'init', array( $this, 'site_page' ), 998 );
			}
		}

		add_shortcode( 'dsgvo', array($this, 'dsgvo_shortcode') );

	}

	public function load_styles() {

		wp_enqueue_style( 'cookie-bar-notification', DSGVO_ASSETS_URL . 'css/cookie-bar-notification.css', array(), null );
		$plugin_css    = '';

		if ( isset($this->options['cookie_bar_background_color']) && $this->options['cookie_bar_background_color'] ) {
			$plugin_css .= "
                .cookie-bar-notification {
                    background-color: ".$this->options['cookie_bar_background_color'].";
                }";
		}

		if ( isset($this->options['cookie_bar_text_color']) && $this->options['cookie_bar_text_color'] ) {
			$plugin_css .= "
                .cookie-bar-notification p {
                    color: ".$this->options['cookie_bar_text_color'].";
                }";
		}

		if ( isset($this->options['cookie_bar_links_color']) && $this->options['cookie_bar_links_color'] ) {
			$plugin_css .= "
                .cookie-bar-notification a {
                    color: ".$this->options['cookie_bar_links_color'].";
                }";
		}

		if ( isset($this->options['cookie_bar_button_background_color']) && $this->options['cookie_bar_button_background_color'] ) {
			$plugin_css .= "
                .cookie-bar-notification-buttons a.button-accept {
                    background-color: ".$this->options['cookie_bar_button_background_color'].";
                }";
		}

		if ( isset($this->options['cookie_bar_button_text_color']) && $this->options['cookie_bar_button_text_color'] ) {

			$plugin_css .= ".cookie-bar-notification-buttons a.button-accept {";

			if(isset($this->options['cookie_bar_button_background_color'])) {
				$plugin_css .= "text-shadow: 0 -1px 1px ".$this->options['cookie_bar_button_background_color'].", 1px 0 1px ".$this->options['cookie_bar_button_background_color'].",0 1px 1px ".$this->options['cookie_bar_button_background_color'].",-1px 0 1px ".$this->options['cookie_bar_button_background_color'].";";
			}

			$plugin_css .= "
                color: ".$this->options['cookie_bar_button_text_color'].";
				line-height: 30px;
				height: 30px;
				padding: 0 10px 1px;
            }";
		}

		if ( isset($this->options['cookie_bar_button_text_color']) && $this->options['cookie_bar_button_text_color'] ) {

			$plugin_css .= ".cookie-bar-notification-buttons a.button-accept {
                color: ".$this->options['cookie_bar_button_text_color'].";
				line-height: 30px;
				height: 30px;
				padding: 0 10px 1px;
            }";

		}

		if ( isset($this->options['cookie_bar_transparency']) && $this->options['cookie_bar_transparency'] ) {
			$transparency = (int)$this->options['cookie_bar_transparency'] / 100;
			$plugin_css .= "
                .cookie-bar-notification {
                    opacity: $transparency;
                }";
		}

		if(isset($this->options['cookie_bar_opt_out_enabled'])) {

			if ( isset($this->options['cookie_bar_optout_link_color']) && $this->options['cookie_bar_optout_link_color'] ) {

				$plugin_css .= ".cookie-bar-notification-buttons a.button-optout {
	                color: ".$this->options['cookie_bar_optout_link_color'].";
					line-height: 30px;
					height: 30px;
					padding: 0 10px 1px;
	            }";

			}

			if ( isset($this->options['cookie_bar_optout_button_bg_color']) && $this->options['cookie_bar_optout_button_bg_color'] ) {

				$plugin_css .= ".cookie-bar-notification-buttons a.button-optout {
	                background: ".$this->options['cookie_bar_optout_button_bg_color'].";
	            }";

			}

		}

		if ( $plugin_css ) {
			$inline_css = preg_replace( "/(^[\r\n]*|[\r\n]+)[\s\t]*[\r\n]+/", "\n", $plugin_css );
			wp_add_inline_style( 'cookie-bar-notification', $inline_css );
		}

	}

	public function load_scripts() {

		$plugin_js = '';

		wp_enqueue_script( 'cookie-bar-notification', DSGVO_ASSETS_URL . 'js/cookie-bar-notification.js', array( 'jquery' ), '', true );

	}

	public function site_page() {
		if(!is_admin() && $GLOBALS['pagenow'] != 'wp-login.php') {
			add_action( 'wp_footer', array( $this, 'cookie_notification_bar' ), 999 );
		}
	}

	private function cookie_bar_position() {
		$options = $this->options;
		return $options['cookie_bar_position'];
	}

	public function cookie_notification_bar() {

		global $sitepress;

		$plugin_options      = $this->options;

		if ( function_exists('icl_object_id') ) {

			$message             = (ICL_LANGUAGE_CODE == $this->default_lang) ? $this->options['cookie_bar_text_message'] : $this->options['cookie_bar_'.ICL_LANGUAGE_CODE.'_text_message'];
			//$message = ICL_LANGUAGE_CODE.'-'.$this->default_lang.'-'.$sitepress->get_default_language();
			$more_info_link_text = (ICL_LANGUAGE_CODE == $this->default_lang) ? $this->options['cookie_bar_url_text'] : $this->options['cookie_bar_'.ICL_LANGUAGE_CODE.'_url_text'];
			$more_info_link      = (ICL_LANGUAGE_CODE == $this->default_lang) ? $this->options['cookie_bar_more_info_url'] : $this->options['cookie_bar_'.ICL_LANGUAGE_CODE.'_more_info_url'];

			$button_text = (ICL_LANGUAGE_CODE == $this->default_lang) ? $this->options['cookie_bar_button_text'] : $this->options['cookie_bar_'.ICL_LANGUAGE_CODE.'_button_text'];
			if(!$button_text) {
				$button_text = 'Accept';
			}

		} else {

			$message             = $this->options['cookie_bar_text_message'];
			$more_info_link_text = $this->options['cookie_bar_url_text'];
			$more_info_link      = $this->options['cookie_bar_more_info_url'];
			$button_text         = $this->options['cookie_bar_button_text'] ? $this->options['cookie_bar_button_text'] : 'Accept';

		}

		$position = $this->cookie_bar_position() === 'whole-width-bottom' ? '' : ' ' . $this->cookie_bar_position();

		if(isset($this->options['cookie_bar_opt_out_enabled'])) {

			$optout 		= 1;
			$optouttype 	= $this->options['cookie_bar_opt_out_type'];
			if($optouttype == 'ga' || $optouttype == 'gtm') {
				if($optouttype == 'ga') {
					$gpropertyid = $this->options['cookie_bar_google_property_id'];
				}
				if($optouttype == 'gtm') {
					$callfunc 	= $this->options['cookie_bar_optout_function_name'];
				}
				$linktext 		= $this->options['cookie_bar_optout_link_text'];
				$successmessage = $this->options['cookie_bar_optout_success_message'];
			} elseif($optouttype == 'custom') {
				$customcode 	= $this->options['cookie_bar_customer_optout_events'];
			}

			$already_accepted_message = $this->options['cookie_bar_optout_already_accepted_message'];

		} else {
			$optout = 0;
		}

		if( strpos($_SERVER['REQUEST_URI'], 'embed') === false ) {
			include __DIR__ . '/views/notification-bar.php';
		}

	}

	public function dsgvo_shortcode($atts) {

		$extractatts = array(
			'type' 						=> '',
			'link_text' 				=> '',
			'success_message' 			=> '',
			'already_optedout_message'  => '',
		);

		if(isset($this->options['cookie_bar_opt_out_type']) && $this->options['cookie_bar_opt_out_type']) {
			if($atts['type'] == 'ga') {
				$extractatts['gproperty'] = '';
			} elseif($atts['type'] == 'gtm') {
				$extractatts['gtmfunc'] = '';
			}
		}

		$atts = shortcode_atts( $extractatts, $atts, 'dsgvo' );

		if(isset($this->options['cookie_bar_opt_out_enabled'])) {

			$optout = 1;
			$optouttype = $atts['type'];
			if($optouttype == 'ga' || $optouttype == 'gtm') {
				if($optouttype == 'ga') {
					$gpropertyid = $atts['gproperty'];
				}
				if($optouttype == 'gtm') {
					$callfunc 	= $atts['gtmfunc'];
				}
				$linktext 		= $atts['link_text'];
				$successmessage = $atts['success_message'];
			} elseif($optouttype == 'custom') {
				$customcode 	= $this->options['cookie_bar_customer_optout_events'];
			}
			$already_accepted_message = $atts['already_optedout_message'];

		} else {

			$optout = 0;

		}

		ob_start();

		include __DIR__ . '/views/notification-shortcode.php';

		return ob_get_clean();

	}

}

new DSGVO_Frontend;
