<?php
/**
 * Plugin & Autoload & Install/Uninstall functions
 *
 * @package     CloudWeb\DSGVO
 * @since       1.0.0
 * @author      cloudweb team @adrian
 * @link        https://www.cloudweb.ch
 * @license     GNU General Public License 2.0+
 *
 */

if ( ! defined( 'ABSPATH' ) ) {
	die( "Oh, silly, there's nothing to see here." );
}

/**
 * Autoload plugin files.
 *
 * @since 1.0.0
 *
 * @return void
 */
function autoload() {
	$files = array(
		'admin/admin.php',
		'frontend/frontend.php',
	);

	foreach( $files as $file ) {
		include( __DIR__ . '/' . $file );
	}
}

autoload();

function single_site_deactivation() {
	delete_option('cookie_bar');
}

function plugin_install( $network_wide ) {
	global $wpdb;
	if ( $network_wide ) {
		if ( function_exists( 'get_sites' ) && function_exists( 'get_current_network_id' ) ) {
			$site_ids = get_sites( array( 'fields' => 'ids', 'network_id' => get_current_network_id() ) );
		} else {
			$site_ids = $wpdb->get_col( "SELECT blog_id FROM $wpdb->blogs WHERE site_id = $wpdb->siteid;" );
		}

		foreach ( $site_ids as $site_id ) {
			switch_to_blog( $site_id );
			restore_current_blog();
		}
	}
}

function plugin_uninstall( $network_wide ) {
	global $wpdb;
	if ( $network_wide ) {
		if ( function_exists( 'get_sites' ) && function_exists( 'get_current_network_id' ) ) {
			$site_ids = get_sites( array( 'fields' => 'ids', 'network_id' => get_current_network_id() ) );
		} else {
			$site_ids = $wpdb->get_col( "SELECT blog_id FROM $wpdb->blogs WHERE site_id = $wpdb->siteid;" );
		}
		foreach ( $site_ids as $site_id ) {
			switch_to_blog( $site_id );
			single_site_deactivation();
			restore_current_blog();
		}
	} else {
		single_site_deactivation();
	}
}

/**
 * Register the plugin.
 *
 * @since 1.0.0
 *
 * @param string $plugin_file
 *
 * @return void
 */
function register_plugin( $plugin_file ) {
	register_activation_hook( $plugin_file, 'plugin_install' );
	register_uninstall_hook( $plugin_file, 'plugin_uninstall' );
}

register_plugin( DSGVO_PLUGIN );
